@@ -99,9 +99,8 @@ class Recipe(BaseSlapRecipe):
     crontabs = os.path.join(self.etc_directory, 'crontabs')
     self._createDirectory(cron_d)
     self._createDirectory(crontabs)
-    # Use execute from erp5.
     wrapper = zc.buildout.easy_install.scripts([('crond',
-      'slapos.recipe.erp5.execute', 'execute')], self.ws, sys.executable,
+      'slapos.recipe.librecipe.execute', 'execute')], self.ws, sys.executable,
       self.wrapper_directory, arguments=[
         self.options['dcrond_binary'].strip(), '-s', cron_d, '-c', crontabs,
         '-t', timestamps, '-f', '-l', '5', '-M', catcher]
@@ -225,7 +224,7 @@ class Recipe(BaseSlapRecipe):
         self.substituteTemplate(template_filename,
           stunnel_conf))
     wrapper = zc.buildout.easy_install.scripts([('stunnel',
-      'slapos.recipe.erp5.execute', 'execute')], self.ws, sys.executable,
+      'slapos.recipe.librecipe.execute', 'execute')], self.ws, sys.executable,
       self.wrapper_directory, arguments=[
         self.options['stunnel_binary'].strip(), stunnel_conf_path]
       )[0]
@@ -310,16 +309,14 @@ class Recipe(BaseSlapRecipe):
         '--defaults-file=%s' % mysql_conf_path,
         '--socket=%s' %mysql_conf['socket'].strip(), '--user=root']
     environment = dict(PATH='%s' % self.bin_directory)
-    # Use execute from erp5.
     innobackupex_incremental = zc.buildout.easy_install.scripts([(
-      'innobackupex_incremental', 'slapos.recipe.erp5.execute', 'executee')],
+      'innobackupex_incremental', 'slapos.recipe.librecipe.execute', 'executee')],
       self.ws, sys.executable, self.bin_directory, arguments=[
         innobackupex_argument_list + ['--incremental'],
         environment])[0]
     self.path_list.append(innobackupex_incremental)
-    # Use execute from erp5.
     innobackupex_full = zc.buildout.easy_install.scripts([('innobackupex_full',
-      'slapos.recipe.erp5.execute', 'executee')], self.ws,
+      'slapos.recipe.librecipe.execute', 'executee')], self.ws,
       sys.executable, self.bin_directory, arguments=[
         innobackupex_argument_list,
         environment])[0]
